==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Vigane andmehoidla",
    "Unknown error" : "Tundmatu viga",
    "All files" : "Kõik failid",
    "Saved" : "Salvestatud",
    "Home" : "Kodu",
    "Close" : "Sulge",
    "Favorites" : "Lemmikud",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Uploading..." : "Üleslaadimine...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faili üleslaadimine on töös. Lehelt lahkumine katkestab selle üleslaadimise.",
    "Actions" : "Tegevused",
    "Download" : "Lae alla",
    "Rename" : "Nimeta ümber",
    "Delete" : "Kustuta",
    "Disconnect storage" : "Ühenda andmehoidla lahti.",
    "Unshare" : "Lõpeta jagamine",
    "Files" : "Failid",
    "Details" : "Üksikasjad",
    "Select" : "Vali",
    "Pending" : "Ootel",
    "Unable to determine date" : "Kuupäeva tuvastamine ei õnnestunud",
    "Invalid path" : "Vigane tee",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval. Palun kontrolli logifaile või võta ühendust administraatoriga",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "{newName} already exists" : "{newName} on juba olemas",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" ümbernimetamine ebaõnnestus",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "Error deleting file \"{fileName}\"." : "Tõrge faili \"{fileName}\" kustutamisel.",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "New" : "Uus",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Sinu {owner} andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "Path" : "Asukoht",
    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
    "Favorited" : "Lemmikud",
    "Favorite" : "Lemmik",
    "Folder" : "Kaust",
    "New folder" : "Uus kaust",
    "{newname} already exists" : "{newname} on juba olemas",
    "Upload" : "Lae üles",
    "An error occurred while trying to update the tags" : "Siltide uuendamisel tekkis tõrge",
    "A new file or folder has been <strong>created</strong>" : "Uus fail või kataloog on <strong>loodud</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fail või kataloog on <strong>muudetud</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fail või kataloog on <strong>kustutatud</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fail või kaust on <strong>taastatud</strong>",
    "You created %1$s" : "Sa tekitasid %1$s",
    "%2$s created %1$s" : "%2$s tekitatud %1$s",
    "%1$s was created in a public folder" : "%1$s lisati avalikku kausta",
    "You changed %1$s" : "Sa muutsid %1$s",
    "%2$s changed %1$s" : "%2$s muutis %1$s",
    "You deleted %1$s" : "Sa kustutasid %1$s",
    "%2$s deleted %1$s" : "%2$s kustutas %1$s",
    "You restored %1$s" : "Sa taastasid %1$s",
    "%2$s restored %1$s" : "%2$s taastas %1$s",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "File handling" : "Failide käsitlemine",
    "Maximum upload size" : "Maksimaalne üleslaadimise suurus",
    "max. possible: " : "maks. võimalik: ",
    "Save" : "Salvesta",
    "Settings" : "Seaded",
    "WebDAV" : "WebDAV",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületab serveri poolt üleslaetavatele failidele määratud maksimaalse suuruse.",
    "No favorites" : "Lemmikuid pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
    "Text file" : "Tekstifail",
    "New text file.txt" : "Uus tekstifail.txt",
    "Unknown user" : "Tundmatu kasutaja"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Vigane andmehoidla",
    "Unknown error" : "Tundmatu viga",
    "All files" : "Kõik failid",
    "Home" : "Kodu",
    "Close" : "Sulge",
    "Favorites" : "Lemmikud",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Uploading..." : "Üleslaadimine...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faili üleslaadimine on töös. Lehelt lahkumine katkestab selle üleslaadimise.",
    "Actions" : "Tegevused",
    "Download" : "Lae alla",
    "Rename" : "Nimeta ümber",
    "Delete" : "Kustuta",
    "Disconnect storage" : "Ühenda andmehoidla lahti.",
    "Unshare" : "Lõpeta jagamine",
    "Files" : "Failid",
    "Details" : "Üksikasjad",
    "Select" : "Vali",
    "Pending" : "Ootel",
    "Unable to determine date" : "Kuupäeva tuvastamine ei õnnestunud",
    "Invalid path" : "Vigane tee",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval. Palun kontrolli logifaile või võta ühendust administraatoriga",
    "group" : "grupp",
    "Remote share" : "Kaugjagamine",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "{newName} already exists" : "{newName} on juba olemas",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" ümbernimetamine ebaõnnestus",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "Error deleting file \"{fileName}\"." : "Tõrge faili \"{fileName}\" kustutamisel.",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "New" : "Uus",
    "Unknown user" : "Tundmatu kasutaja",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Sinu {owner} andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "Path" : "Asukoht",
    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
    "Favorited" : "Lemmikud",
    "Favorite" : "Lemmik",
    "Folder" : "Kaust",
    "New folder" : "Uus kaust",
    "{newname} already exists" : "{newname} on juba olemas",
    "Upload" : "Lae üles",
    "An error occurred while trying to update the tags" : "Siltide uuendamisel tekkis tõrge",
    "A new file or folder has been <strong>created</strong>" : "Uus fail või kataloog on <strong>loodud</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fail või kataloog on <strong>muudetud</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fail või kataloog on <strong>kustutatud</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fail või kaust on <strong>taastatud</strong>",
    "You created %1$s" : "Sa tekitasid %1$s",
    "%2$s created %1$s" : "%2$s tekitatud %1$s",
    "%1$s was created in a public folder" : "%1$s lisati avalikku kausta",
    "You changed %1$s" : "Sa muutsid %1$s",
    "%2$s changed %1$s" : "%2$s muutis %1$s",
    "You deleted %1$s" : "Sa kustutasid %1$s",
    "%2$s deleted %1$s" : "%2$s kustutas %1$s",
    "You restored %1$s" : "Sa taastasid %1$s",
    "%2$s restored %1$s" : "%2$s taastas %1$s",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "Settings" : "Seaded",
    "WebDAV" : "WebDAV",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületab serveri poolt üleslaetavatele failidele määratud maksimaalse suuruse.",
    "No favorites" : "Lemmikuid pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
    "Text file" : "Tekstifail",
    "New text file.txt" : "Uus tekstifail.txt"
},
"nplurals=2; plural=(n != 1);");
